@@ -4,7 +4,7 @@ set -e #exit on error
 
 usage() {
     prog=`basename "$0"`
-    echo "Usage: $prog --eol|'' --indent-spaces|--indent-tabs|'' indent_width filename" >&2
+    echo "Usage: $prog --eol|'' --indent-spaces|--indent-tabs|'' indent_width|'' filename" >&2
     exit 1
 }
 
@@ -27,16 +27,19 @@ trap 'rm -f "$TMP"' EXIT
 
 
 if [ "$1" = "--eol" ]; then
+    #Note \t is a GNU extension
     STRIP_EOL_SPACES="sed -e 's/[ 	]*$//'"
 fi
 
 if [ "$2" = "--indent-spaces" ]; then
     # Sigh. `expand --initial` is buggy in coreutils-5.2.1 at least.
     # It ignores tabs after spaces which you can check with:
-    # echo -e " \tif" | expand --initial -t4 | grep -qF ' ' && echo buggy
+    # printf " \tif\n" | expand --initial -t4 | grep -qF ' ' && echo buggy
     # It's fixed in coreutils-6.2 at least and probably much earlier,
     # but since the buggy version is in FC4 and ubuntu 5.10
     # we had better work around it by running `unexpand` first.
+    # Hmm still buggy in ubuntu feisty (coreutils-5.97) and
+    # fedora 8 (coreutils-6.9), probably due to i18n patch?
     TAB_CONVERT="unexpand --first-only -t$3"
     TAB_CONVERT="$TAB_CONVERT | expand --initial -t$3"
 elif [ "$2" = "--indent-tabs" ]; then
@@ -51,5 +54,5 @@ fi
 
 [ "$COMMAND" ] || usage
 
-cat -- "$FILE" | eval $COMMAND > "$TMP"
+cat -- "$FILE" | eval "$COMMAND" > "$TMP"
 $CMP -s "$TMP" "$FILE" || mv -f "$TMP" "$FILE"
